@@ -1,4 +1,4 @@
-from src.arxivAssistant.app import ArxivApp
+from arxivAssistant.app import ArxivApp
 
 
 def main() -> None:
